summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/formeditor')
-rw-r--r--kexi/formeditor/commands.cpp40
-rw-r--r--kexi/formeditor/commands.h2
-rw-r--r--kexi/formeditor/connectiondialog.cpp2
-rw-r--r--kexi/formeditor/container.cpp54
-rw-r--r--kexi/formeditor/factories/containerfactory.cpp10
-rw-r--r--kexi/formeditor/factories/stdwidgetfactory.cpp8
-rw-r--r--kexi/formeditor/form.cpp4
-rw-r--r--kexi/formeditor/form.h4
-rw-r--r--kexi/formeditor/formIO.cpp20
-rw-r--r--kexi/formeditor/formmanager.cpp14
-rw-r--r--kexi/formeditor/formmanager.h6
-rw-r--r--kexi/formeditor/objecttree.cpp12
-rw-r--r--kexi/formeditor/objecttree.h6
-rw-r--r--kexi/formeditor/objecttreeview.cpp2
-rw-r--r--kexi/formeditor/richtextdialog.cpp2
-rw-r--r--kexi/formeditor/richtextdialog.h2
-rw-r--r--kexi/formeditor/scripting/formscript.cpp2
-rw-r--r--kexi/formeditor/spring.cpp2
-rw-r--r--kexi/formeditor/tdevelop_plugin/kfd_kdev_part.cpp8
-rw-r--r--kexi/formeditor/test/kfd_part.cpp12
-rw-r--r--kexi/formeditor/utils.cpp4
-rw-r--r--kexi/formeditor/utils.h6
-rw-r--r--kexi/formeditor/widgetfactory.cpp10
-rw-r--r--kexi/formeditor/widgetfactory.h6
-rw-r--r--kexi/formeditor/widgetlibrary.cpp6
-rw-r--r--kexi/formeditor/widgetpropertyset.cpp28
-rw-r--r--kexi/formeditor/widgetpropertyset.h8
27 files changed, 140 insertions, 140 deletions
diff --git a/kexi/formeditor/commands.h b/kexi/formeditor/commands.h
index 64e5a2536..ad468261c 100644
--- a/kexi/formeditor/commands.h
+++ b/kexi/formeditor/commands.h
@@ -105,7 +105,7 @@ class KFORMEDITOR_EXPORT GeometryPropertyCommand : public Command
/*! This command is used when an item in 'Align Widgets position' is selected. You just need
to give the list of widget names (the selected ones), and the
- type of tqalignment (see the enum for possible values). */
+ type of alignment (see the enum for possible values). */
class KFORMEDITOR_EXPORT AlignWidgetsCommand : public Command
{
public:
diff --git a/kexi/formeditor/connectiondialog.cpp b/kexi/formeditor/connectiondialog.cpp
index 38b6e08e9..e1dcf1bed 100644
--- a/kexi/formeditor/connectiondialog.cpp
+++ b/kexi/formeditor/connectiondialog.cpp
@@ -334,7 +334,7 @@ ConnectionDialog::checkConnection(KexiTableItem *item)
{
if( !item || (*item)[i].toString().isEmpty())
{
- setStatusError( i18n("<qt>You have not selected item: <b>%1</b>.</qt>").tqarg(m_data->column(i)->captionAliasOrName()),
+ setStatusError( i18n("<qt>You have not selected item: <b>%1</b>.</qt>").arg(m_data->column(i)->captionAliasOrName()),
item);
return;
}
diff --git a/kexi/formeditor/factories/containerfactory.cpp b/kexi/formeditor/factories/containerfactory.cpp
index 2e30d5f40..e41e5613b 100644
--- a/kexi/formeditor/factories/containerfactory.cpp
+++ b/kexi/formeditor/factories/containerfactory.cpp
@@ -256,7 +256,7 @@ InsertPageCommand::execute()
if(classname == "KFDTabWidget")
{
TabWidgetBase *tab = dynamic_cast<TabWidgetBase*>(parent);
- TQString n = i18n("Page %1").tqarg(tab->count() + 1);
+ TQString n = i18n("Page %1").arg(tab->count() + 1);
tab->addTab(page, n);
tab->showPage(page);
@@ -455,7 +455,7 @@ ContainerFactory::ContainerFactory(TQObject *parent, const char *, const TQStrin
wSplitter->setName(i18n("Splitter"));
wSplitter->setNamePrefix(
i18n("Widget name. This string will be used to name widgets of this class. It must _not_ contain white spaces and non latin1 characters.", "splitter"));
- wSplitter->setDescription(i18n("A container that enables user to resize its tqchildren"));
+ wSplitter->setDescription(i18n("A container that enables user to resize its children"));
addClass(wSplitter);
KFormDesigner::WidgetInfo *wHFlow = new KFormDesigner::WidgetInfo(this);
@@ -682,7 +682,7 @@ ContainerFactory::createMenuActions(const TQCString &classname, TQWidget *w, TQP
int id = menu->insertItem(SmallIconSet("tab_new"), i18n("Add Page"), this, TQT_SLOT(addStackPage()) );
id = menu->insertItem(SmallIconSet("tab_remove"), i18n("Remove Page"), this, TQT_SLOT(removeStackPage()) );
-// if( ((TQWidgetStack*)m_widget)->tqchildren()->count() == 4) // == the stack has only one page
+// if( ((TQWidgetStack*)m_widget)->children()->count() == 4) // == the stack has only one page
if(stack->childrenListObject().count() == 4) // == the stack has only one page
menu->setItemEnabled(id, false);
@@ -872,8 +872,8 @@ void ContainerFactory::reorderTabs(int oldpos, int newpos)
if(!tab)
return;
- KFormDesigner::ObjectTreeItem *item = tab->tqchildren()->take(oldpos);
- tab->tqchildren()->insert(newpos, item);
+ KFormDesigner::ObjectTreeItem *item = tab->children()->take(oldpos);
+ tab->children()->insert(newpos, item);
}
void ContainerFactory::addStackPage()
diff --git a/kexi/formeditor/factories/stdwidgetfactory.cpp b/kexi/formeditor/factories/stdwidgetfactory.cpp
index afc370867..2607fcca7 100644
--- a/kexi/formeditor/factories/stdwidgetfactory.cpp
+++ b/kexi/formeditor/factories/stdwidgetfactory.cpp
@@ -492,7 +492,7 @@ StdWidgetFactory::startEditing(const TQCString &classname, TQWidget *w, KFormDes
if(classname == "KLineEdit")
{
KLineEdit *lineedit = static_cast<KLineEdit*>(w);
- createEditor(classname, lineedit->text(), lineedit, container, lineedit->tqgeometry(), lineedit->tqalignment(), true);
+ createEditor(classname, lineedit->text(), lineedit, container, lineedit->geometry(), lineedit->alignment(), true);
return true;
}
else if(classname == TQLABEL_OBJECT_NAME_STRING)
@@ -505,7 +505,7 @@ StdWidgetFactory::startEditing(const TQCString &classname, TQWidget *w, KFormDes
editText();
}
else
- createEditor(classname, label->text(), label, container, label->tqgeometry(), label->tqalignment());
+ createEditor(classname, label->text(), label, container, label->geometry(), label->alignment());
return true;
}
else if(classname == "KPushButton")
@@ -531,7 +531,7 @@ StdWidgetFactory::startEditing(const TQCString &classname, TQWidget *w, KFormDes
else if(classname == TQCHECKBOX_OBJECT_NAME_STRING)
{
TQCheckBox *check = static_cast<TQCheckBox*>(w);
- //TQRect r(check->tqgeometry());
+ //TQRect r(check->geometry());
//r.setX(r.x() + 20);
TQRect r = w->tqstyle().subRect(TQStyle::SR_CheckBoxContents, w);
TQRect editorRect = TQRect(check->x() + r.x(), check->y() + r.y(), r.width(), r.height());
@@ -860,7 +860,7 @@ StdWidgetFactory::isPropertyVisibleInternal(const TQCString &classname,
}
else if(classname == "KexiPictureLabel")
{
- if((property == "text") || (property == "indent") || (property == "textFormat") || (property == "font") || (property == "tqalignment"))
+ if((property == "text") || (property == "indent") || (property == "textFormat") || (property == "font") || (property == "alignment"))
return false;
}
else if(classname == TQLABEL_OBJECT_NAME_STRING)
diff --git a/kexi/formeditor/form.cpp b/kexi/formeditor/form.cpp
index 237c7ec83..6ed3e570d 100644
--- a/kexi/formeditor/form.cpp
+++ b/kexi/formeditor/form.cpp
@@ -365,7 +365,7 @@ Form::changeName(const TQCString &oldname, const TQCString &newname)
if(!d->topTree->rename(oldname, newname)) // rename failed
{
KMessageBox::sorry(widget()->topLevelWidget(),
- i18n("Renaming widget \"%1\" to \"%2\" failed.").tqarg(TQString(oldname)).tqarg(TQString(newname)));
+ i18n("Renaming widget \"%1\" to \"%2\" failed.").arg(TQString(oldname)).arg(TQString(newname)));
//moved to WidgetPropertySet::slotChangeProperty()
// KMessageBox::sorry(widget()->topLevelWidget(),
// i18n("A widget with this name already exists. "
@@ -499,7 +499,7 @@ void collectContainers(ObjectTreeItem* item, TQPtrDict<char>& containers)
<< " " << item->container()->objectTree()->name() << endl;
containers.insert( item->container(), (const char *)1 );
}
- for (ObjectTreeListIterator it(*item->tqchildren()); it.current(); ++it)
+ for (ObjectTreeListIterator it(*item->children()); it.current(); ++it)
collectContainers(it.current(), containers);
}
diff --git a/kexi/formeditor/form.h b/kexi/formeditor/form.h
index 7df731c6c..9bb68925a 100644
--- a/kexi/formeditor/form.h
+++ b/kexi/formeditor/form.h
@@ -67,7 +67,7 @@ class KFORMEDITOR_EXPORT FormWidget
/*! This function inits the buffer used for double-buffering. Called before drawing rect. */
virtual void initBuffer() = 0;
- /*! Clears the form, ie pastes the whole buffer to tqrepaint the Form. */
+ /*! Clears the form, ie pastes the whole buffer to repaint the Form. */
virtual void clearForm() = 0;
/*! This function highlights two widgets (to is optional), which are
@@ -109,7 +109,7 @@ class FormPrivate
PixmapCollection *pixcollection;
- //! This map is used to store cursor tqshapes before inserting (so we can restore them later)
+ //! This map is used to store cursor shapes before inserting (so we can restore them later)
TQMap<TQObject*,TQCursor> cursors;
//!This string list is used to store the widgets which hasMouseTracking() == true (eg lineedits)
diff --git a/kexi/formeditor/formmanager.cpp b/kexi/formeditor/formmanager.cpp
index 5fb76ca89..f75a4232b 100644
--- a/kexi/formeditor/formmanager.cpp
+++ b/kexi/formeditor/formmanager.cpp
@@ -413,7 +413,7 @@ FormManager::resetCreatedConnection()
m_active->formWidget()->clearForm();
}
if (m_active && m_active->widget())
- m_active->widget()->tqrepaint();
+ m_active->widget()->repaint();
}
void
@@ -863,14 +863,14 @@ FormManager::createContextMenu(TQWidget *w, Container *container, bool popupAtCu
if(!multiple)
{
if(w == container->form()->widget())
- m_popup->insertTitle(SmallIcon("form"), i18n("%1 : Form").tqarg(w->name()) );
+ m_popup->insertTitle(SmallIcon("form"), i18n("%1 : Form").arg(w->name()) );
else
m_popup->insertTitle( SmallIcon(
container->form()->library()->iconName(w->className())), TQString(w->name()) + " : " + n );
}
else
m_popup->insertTitle(SmallIcon("multiple_obj"), i18n("Multiple Widgets")
- + TQString(" (%1)").tqarg(widgetsCount));
+ + TQString(" (%1)").arg(widgetsCount));
KAction *a;
#define PLUG_ACTION(_name, forceVisible) \
@@ -1380,9 +1380,9 @@ FormManager::selectAll()
return;
activeForm()->selectFormWidget();
- uint count = activeForm()->objectTree()->tqchildren()->count();
- for(ObjectTreeItem *it = activeForm()->objectTree()->tqchildren()->first(); it;
- it = activeForm()->objectTree()->tqchildren()->next(), count--)
+ uint count = activeForm()->objectTree()->children()->count();
+ for(ObjectTreeItem *it = activeForm()->objectTree()->children()->first(); it;
+ it = activeForm()->objectTree()->children()->next(), count--)
{
activeForm()->setSelectedWidget(it->widget(), /*add*/true, /*raise*/false, /*moreWillBeSelected*/count>1);
}
@@ -1550,7 +1550,7 @@ FormManager::emitFormWidgetSelected( KFormDesigner::Form* form )
enableFormActions();
const bool twoSelected = form->selectedWidgets()->count()==2;
- const bool hasChildren = !form->objectTree()->tqchildren()->isEmpty();
+ const bool hasChildren = !form->objectTree()->children()->isEmpty();
// Layout actions
enableAction("layout_menu", hasChildren);
diff --git a/kexi/formeditor/formmanager.h b/kexi/formeditor/formmanager.h
index a43100fff..f5c72d731 100644
--- a/kexi/formeditor/formmanager.h
+++ b/kexi/formeditor/formmanager.h
@@ -221,13 +221,13 @@ class KFORMEDITOR_EXPORT FormManager : public TQObject
bool isRedoing() const { return m_isRedoing; }
public slots:
- /*! Deletes the selected widget in active Form and all of its tqchildren. */
+ /*! Deletes the selected widget in active Form and all of its children. */
void deleteWidget();
- /*! Copies the slected widget and all its tqchildren of the active Form using an XML representation. */
+ /*! Copies the slected widget and all its children of the active Form using an XML representation. */
void copyWidget();
- /*! Cuts (ie Copies and deletes) the selected widget and all its tqchildren of
+ /*! Cuts (ie Copies and deletes) the selected widget and all its children of
the active Form using an XML representation. */
void cutWidget();
diff --git a/kexi/formeditor/objecttree.cpp b/kexi/formeditor/objecttree.cpp
index e2ada7143..fa86e8048 100644
--- a/kexi/formeditor/objecttree.cpp
+++ b/kexi/formeditor/objecttree.cpp
@@ -64,14 +64,14 @@ ObjectTreeItem::rename(const TQString &name)
void
ObjectTreeItem::addChild(ObjectTreeItem *c)
{
- m_tqchildren.append(c);
+ m_children.append(c);
c->setParent(this);
}
void
ObjectTreeItem::removeChild(ObjectTreeItem *c)
{
- m_tqchildren.remove(c);
+ m_children.remove(c);
}
void
@@ -141,10 +141,10 @@ ObjectTree::ObjectTree(const TQString &classn, const TQString &name, TQWidget *w
ObjectTree::~ObjectTree()
{
-// for(ObjectTreeItem *it = tqchildren()->first(); it; it = tqchildren()->next())
+// for(ObjectTreeItem *it = children()->first(); it; it = children()->next())
// removeItem(it->name());
- while (tqchildren()->first()) {
- removeItem(tqchildren()->first());
+ while (children()->first()) {
+ removeItem(children()->first());
}
}
@@ -216,7 +216,7 @@ ObjectTree::removeItem(ObjectTreeItem *c)
if (m_container && m_container->form())
m_container->form()->emitChildRemoved(c);
- for(ObjectTreeItem *it = c->tqchildren()->first(); it; it = c->tqchildren()->next())
+ for(ObjectTreeItem *it = c->children()->first(); it; it = c->children()->next())
removeItem(it->name());
m_treeDict.remove(c->name());
diff --git a/kexi/formeditor/objecttree.h b/kexi/formeditor/objecttree.h
index b37d7caa8..eaa95a0c9 100644
--- a/kexi/formeditor/objecttree.h
+++ b/kexi/formeditor/objecttree.h
@@ -58,7 +58,7 @@ typedef TQMapConstIterator<TQString, TQVariant> TQVariantMapConstIterator;
/*!
@short An item representing a widget
- Holds the properties of a widget (classname, name, parent, tqchildren ..).
+ Holds the properties of a widget (classname, name, parent, children ..).
@author Lucijan Busch <lucijan@kde.org>
*/
class KFORMEDITOR_EXPORT ObjectTreeItem
@@ -72,7 +72,7 @@ class KFORMEDITOR_EXPORT ObjectTreeItem
TQWidget* widget() const { return m_widget; }
EventEater* eventEater() const { return m_eater; }
ObjectTreeItem* parent() const { return m_parent; }
- ObjectTreeList* tqchildren() { return &m_tqchildren; }
+ ObjectTreeList* children() { return &m_children; }
/*! \return a TQMap<TQString, TQVariant> of all modified properties for this widget.
The TQVariant is the old value (ie first value) of the property whose name is the TQString. */
@@ -121,7 +121,7 @@ class KFORMEDITOR_EXPORT ObjectTreeItem
protected:
TQString m_className;
TQString m_name;
- ObjectTreeList m_tqchildren;
+ ObjectTreeList m_children;
TQGuardedPtr<Container> m_container;
TQMap<TQString, TQVariant> m_props;
TQMap<TQString, TQVariant> *m_subprops;
diff --git a/kexi/formeditor/objecttreeview.cpp b/kexi/formeditor/objecttreeview.cpp
index ba48214bf..82cb67bb7 100644
--- a/kexi/formeditor/objecttreeview.cpp
+++ b/kexi/formeditor/objecttreeview.cpp
@@ -367,7 +367,7 @@ ObjectTreeView::loadTree(ObjectTreeItem *item, ObjectTreeViewItem *parent)
last = last->nextSibling();
treeItem->moveItem(last);
- ObjectTreeList *list = item->tqchildren();
+ ObjectTreeList *list = item->children();
for(ObjectTreeItem *it = list->first(); it; it = list->next())
loadTree(it, treeItem);
diff --git a/kexi/formeditor/richtextdialog.cpp b/kexi/formeditor/richtextdialog.cpp
index e3b73975d..a8605e7b5 100644
--- a/kexi/formeditor/richtextdialog.cpp
+++ b/kexi/formeditor/richtextdialog.cpp
@@ -168,7 +168,7 @@ RichTextDialog::cursorPositionChanged(int, int)
m_toolbar->setButton(TBUnder, m_edit->underline());
int id = 0;
- switch(m_edit->tqalignment())
+ switch(m_edit->alignment())
{
case TQt::AlignLeft: id = TBLeft; break;
case TQt::AlignCenter: id = TBCenter; break;
diff --git a/kexi/formeditor/richtextdialog.h b/kexi/formeditor/richtextdialog.h
index 25150873a..f5ae41ea7 100644
--- a/kexi/formeditor/richtextdialog.h
+++ b/kexi/formeditor/richtextdialog.h
@@ -30,7 +30,7 @@ class KColorCombo;
namespace KFormDesigner {
//! A simple dialog to edit rich text
-/*! It allows to change font name, style and color, tqalignment. */
+/*! It allows to change font name, style and color, alignment. */
class KFORMEDITOR_EXPORT RichTextDialog : public KDialogBase
{
Q_OBJECT
diff --git a/kexi/formeditor/scripting/formscript.cpp b/kexi/formeditor/scripting/formscript.cpp
index 1123e0934..aa32bc029 100644
--- a/kexi/formeditor/scripting/formscript.cpp
+++ b/kexi/formeditor/scripting/formscript.cpp
@@ -71,7 +71,7 @@ FormScript::execute(const TQString &functionName)
m_script->callFunction(functionName);
}
catch(Kross::Api::Exception& e) {
- kdDebug() << TQString("EXCEPTION type='%1' description='%2'").tqarg(e.type()).tqarg(e.description()) << endl;
+ kdDebug() << TQString("EXCEPTION type='%1' description='%2'").arg(e.type()).arg(e.description()) << endl;
return false;
}
return true;
diff --git a/kexi/formeditor/spring.cpp b/kexi/formeditor/spring.cpp
index 074b8810f..3e0651b19 100644
--- a/kexi/formeditor/spring.cpp
+++ b/kexi/formeditor/spring.cpp
@@ -47,7 +47,7 @@ Spring::setOrientation(Qt::Orientation orient)
SizeType type = sizeType();
m_orient = orient;
setSizeType(type);
- tqrepaint();
+ repaint();
}
Spring::SizeType
diff --git a/kexi/formeditor/tdevelop_plugin/kfd_kdev_part.cpp b/kexi/formeditor/tdevelop_plugin/kfd_kdev_part.cpp
index 09549ddc4..1a7b7dda7 100644
--- a/kexi/formeditor/tdevelop_plugin/kfd_kdev_part.cpp
+++ b/kexi/formeditor/tdevelop_plugin/kfd_kdev_part.cpp
@@ -323,7 +323,7 @@ KFormDesignerKDevPart::closeForm(Form *form)
{
int res = KMessageBox::warningYesNoCancel( m_workspace->topLevelWidget(),
i18n( "The form \"%1\" has been modified.\n"
- "Do you want to save your changes or discard them?" ).tqarg( form->objectTree()->name() ),
+ "Do you want to save your changes or discard them?" ).arg( form->objectTree()->name() ),
i18n( "Close Form" ), KStdGuiItem::save(), KStdGuiItem::discard() );
if(res == KMessageBox::Yes)
@@ -535,13 +535,13 @@ KFormDesignerKDevPart::~KFormDesignerKDevPart()
////// FormWidgetBase : helper widget to draw rects on top of widgets
-//tqrepaint all tqchildren widgets
+//repaint all children widgets
static void repaintAll(TQWidget *w)
{
TQObjectList *list = w->queryList(TQWIDGET_OBJECT_NAME_STRING);
TQObjectListIt it(*list);
for (TQObject *obj; (obj=it.current()); ++it ) {
- static_cast<TQWidget*>(obj)->tqrepaint();
+ static_cast<TQWidget*>(obj)->repaint();
}
delete list;
}
@@ -639,7 +639,7 @@ FormWidgetBase::highlightWidgets(TQWidget *from, TQWidget *to)//, const TQPoint
TQPixmap pix2 = TQPixmap::grabWidget(to);
if((from != this) && (to != this))
- p.drawLine( from->parentWidget()->mapTo(this, from->tqgeometry().center()), to->parentWidget()->mapTo(this, to->tqgeometry().center()) );
+ p.drawLine( from->parentWidget()->mapTo(this, from->geometry().center()), to->parentWidget()->mapTo(this, to->geometry().center()) );
p.drawPixmap(fromPoint.x(), fromPoint.y(), pix1);
p.drawPixmap(toPoint.x(), toPoint.y(), pix2);
diff --git a/kexi/formeditor/test/kfd_part.cpp b/kexi/formeditor/test/kfd_part.cpp
index 386bdabfc..07e7edfdc 100644
--- a/kexi/formeditor/test/kfd_part.cpp
+++ b/kexi/formeditor/test/kfd_part.cpp
@@ -344,7 +344,7 @@ KFormDesignerPart::closeForm(Form *form)
{
int res = KMessageBox::questionYesNoCancel( m_workspace->topLevelWidget(),
i18n( "The form \"%1\" has been modified.\n"
- "Do you want to save your changes or discard them?" ).tqarg( form->objectTree()->name() ),
+ "Do you want to save your changes or discard them?" ).arg( form->objectTree()->name() ),
i18n( "Close Form" ), KStdGuiItem::save(), KStdGuiItem::discard() );
if(res == KMessageBox::Yes)
@@ -451,7 +451,7 @@ KFormDesignerPart::slotFormWidgetSelected(Form *form)
enableFormActions();
const bool twoSelected = form->selectedWidgets()->count()==2;
- const bool hasChildren = !form->objectTree()->tqchildren()->isEmpty();
+ const bool hasChildren = !form->objectTree()->children()->isEmpty();
// Layout actions
ENABLE_ACTION("layout_menu", hasChildren);
@@ -558,14 +558,14 @@ KFormDesignerPart::setRedoEnabled(bool enabled, const TQString &text)
////// FormWidgetBase : helper widget to draw rects on top of widgets
-//tqrepaint all tqchildren widgets
+//repaint all children widgets
static void repaintAll(TQWidget *w)
{
- w->tqrepaint();
+ w->repaint();
TQObjectList *list = w->queryList(TQWIDGET_OBJECT_NAME_STRING);
TQObjectListIt it(*list);
for (TQObject *obj; (obj=it.current()); ++it ) {
- static_cast<TQWidget*>(obj)->tqrepaint();
+ static_cast<TQWidget*>(obj)->repaint();
}
delete list;
}
@@ -663,7 +663,7 @@ FormWidgetBase::highlightWidgets(TQWidget *from, TQWidget *to)//, const TQPoint
TQPixmap pix2 = TQPixmap::grabWidget(to);
if((from != this) && (to != this))
- p.drawLine( from->parentWidget()->mapTo(this, from->tqgeometry().center()), to->parentWidget()->mapTo(this, to->tqgeometry().center()) );
+ p.drawLine( from->parentWidget()->mapTo(this, from->geometry().center()), to->parentWidget()->mapTo(this, to->geometry().center()) );
p.drawPixmap(fromPoint.x(), fromPoint.y(), pix1);
p.drawPixmap(toPoint.x(), toPoint.y(), pix2);
diff --git a/kexi/formeditor/utils.cpp b/kexi/formeditor/utils.cpp
index 85e932045..53a9a15b9 100644
--- a/kexi/formeditor/utils.cpp
+++ b/kexi/formeditor/utils.cpp
@@ -88,7 +88,7 @@ void
KFormDesigner::setRecursiveCursor(TQWidget *w, Form *form)
{
ObjectTreeItem *tree = form->objectTree()->lookup(w->name());
- if(tree && ((tree->modifiedProperties()->contains("cursor")) || !tree->tqchildren()->isEmpty())
+ if(tree && ((tree->modifiedProperties()->contains("cursor")) || !tree->children()->isEmpty())
&& !w->inherits(TQLINEEDIT_OBJECT_NAME_STRING) && !w->inherits(TQTEXTEDIT_OBJECT_NAME_STRING)
) //fix weird behaviour
return; // if the user has set a cursor for this widget or this is a container, don't change it
@@ -108,7 +108,7 @@ KFormDesigner::getSizeFromChildren(TQWidget *w, const char *inheritClass)
int tmpw = 0, tmph = 0;
TQObjectList *list = w->queryList(inheritClass, 0, false, false);
for(TQObject *o = list->first(); o; o = list->next()) {
- TQRect r = ((TQWidget*)o)->tqgeometry();
+ TQRect r = ((TQWidget*)o)->geometry();
tmpw = TQMAX(tmpw, r.right());
tmph = TQMAX(tmph, r.bottom());
}
diff --git a/kexi/formeditor/widgetfactory.cpp b/kexi/formeditor/widgetfactory.cpp
index 61688ac62..9bec64ba4 100644
--- a/kexi/formeditor/widgetfactory.cpp
+++ b/kexi/formeditor/widgetfactory.cpp
@@ -183,7 +183,7 @@ void WidgetFactory::hideClass(const char *classname)
void
WidgetFactory::createEditor(const TQCString &classname, const TQString &text,
- TQWidget *w, Container *container, TQRect tqgeometry,
+ TQWidget *w, Container *container, TQRect geometry,
int align, bool useFrame, bool multiLine, BackgroundMode background)
{
//#ifdef KEXI_KTEXTEDIT
@@ -198,7 +198,7 @@ WidgetFactory::createEditor(const TQCString &classname, const TQString &text,
textedit->setPalette(w->palette());
textedit->setFont(w->font());
textedit->setResizePolicy(TQScrollView::Manual);
- textedit->setGeometry(tqgeometry);
+ textedit->setGeometry(geometry);
if(background == TQt::NoBackground)
textedit->setBackgroundMode(w->backgroundMode());
else
@@ -232,7 +232,7 @@ WidgetFactory::createEditor(const TQCString &classname, const TQString &text,
editor->setAlignment(align);
editor->setPalette(w->palette());
editor->setFont(w->font());
- editor->setGeometry(tqgeometry);
+ editor->setGeometry(geometry);
if(background == TQt::NoBackground)
editor->setBackgroundMode(w->backgroundMode());
else
@@ -317,7 +317,7 @@ WidgetFactory::editList(TQWidget *w, TQStringList &list)
KDialogBase dialog(w->topLevelWidget(), "stringlist_dialog", true, i18n("Edit List of Items"),
KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, false);
- KEditListBox *edit = new KEditListBox(i18n("Contents of %1").tqarg(w->name()), &dialog, "editlist");
+ KEditListBox *edit = new KEditListBox(i18n("Contents of %1").arg(w->name()), &dialog, "editlist");
dialog.setMainWidget(edit);
edit->insertStringList(list);
// edit->show();
@@ -456,7 +456,7 @@ WidgetFactory::resetEditor()
if(m_widget)
{
disconnect(m_widget, 0, this, 0);
- m_widget->tqrepaint();
+ m_widget->repaint();
}
//js delete m_handles;
diff --git a/kexi/formeditor/widgetfactory.h b/kexi/formeditor/widgetfactory.h
index 9e5856255..7c9c5ceb1 100644
--- a/kexi/formeditor/widgetfactory.h
+++ b/kexi/formeditor/widgetfactory.h
@@ -384,10 +384,10 @@ class KFORMEDITOR_EXPORT WidgetFactory : public TQObject
/*! This function creates a KLineEdit to input some text and edit a widget's contents.
This can be used in startEditing(). \a text is the text to display by default
- in the line edit, \a w is the edited widget, \a tqgeometry is the tqgeometry the new line
+ in the line edit, \a w is the edited widget, \a geometry is the geometry the new line
edit should have, and \a align is TQt::AlignmentFlags of the new line edit. */
void createEditor(const TQCString &classname, const TQString &text,
- TQWidget *w, Container *container, TQRect tqgeometry,
+ TQWidget *w, Container *container, TQRect geometry,
int align, bool useFrame=false, bool multiLine = false,
BackgroundMode background = TQt::NoBackground);
@@ -403,7 +403,7 @@ class KFORMEDITOR_EXPORT WidgetFactory : public TQObject
into \a list when the user presses "Ok".*/
bool editList(TQWidget *w, TQStringList &list);
- /*! This function creates a little editor to modify rich text. It supports tqalignment,
+ /*! This function creates a little editor to modify rich text. It supports alignment,
subscript and superscript and all basic formatting properties.
If the user presses "Ok", the edited text is put in \a text.
If he presses "Cancel", nothing happens. */
diff --git a/kexi/formeditor/widgetlibrary.cpp b/kexi/formeditor/widgetlibrary.cpp
index 9a680db5c..953b220b0 100644
--- a/kexi/formeditor/widgetlibrary.cpp
+++ b/kexi/formeditor/widgetlibrary.cpp
@@ -219,8 +219,8 @@ WidgetLibrary::lookupFactories()
if (KFormDesigner::version()!=factoryVersion) {
kdWarning() << TQString("WidgetLibrary::lookupFactories(): factory '%1'"
" has version '%2' but required Widget Factory version is '%3'\n"
- " -- skipping this factory!").tqarg(ptr->library()).tqarg(factoryVersion)
- .tqarg(KFormDesigner::version()) << endl;
+ " -- skipping this factory!").arg(ptr->library()).arg(factoryVersion)
+ .arg(KFormDesigner::version()) << endl;
continue;
}
d->services.insert(ptr->library().latin1(), new KService::Ptr( ptr ));
@@ -739,7 +739,7 @@ WidgetFactory::CreateWidgetOptions WidgetLibrary::showOrientationSelectionPopup(
textVertical = i18n("InsertQt::Vertical Widget", "InsertQt::Vertical");
KPopupMenu* popup = new KPopupMenu(parent, "orientationSelectionPopup");
- popup->insertTitle(SmallIcon(wclass->pixmap()), i18n("Insert Widget: %1").tqarg(wclass->name()));
+ popup->insertTitle(SmallIcon(wclass->pixmap()), i18n("Insert Widget: %1").arg(wclass->name()));
popup->insertItem(iconHorizontal, textHorizontal, 1);
popup->insertItem(iconVertical, textVertical, 2);
popup->insertSeparator();
diff --git a/kexi/formeditor/commands.cpp b/kexi/formeditor/commands.cpp
index 241a1291b..a2cddd891 100644
--- a/kexi/formeditor/commands.cpp
+++ b/kexi/formeditor/commands.cpp
@@ -139,9 +139,9 @@ TQString
PropertyCommand::name() const
{
if(m_oldvalues.count() >= 2)
- return i18n("Change \"%1\" property for multiple widgets" ).tqarg(TQString(m_property));
+ return i18n("Change \"%1\" property for multiple widgets" ).arg(TQString(m_property));
else
- return i18n("Change \"%1\" property for widget \"%2\"" ).tqarg(TQString(m_property)).tqarg(TQString(m_oldvalues.begin().key()));
+ return i18n("Change \"%1\" property for widget \"%2\"" ).arg(TQString(m_property)).arg(TQString(m_oldvalues.begin().key()));
}
void
@@ -435,7 +435,7 @@ AdjustSizeCommand::execute()
{
for(TQWidget *w = list.first(); w; w = list.next()) {
ObjectTreeItem *item = m_form->objectTree()->lookup(w->name());
- if(item && !item->tqchildren()->isEmpty()) { // container
+ if(item && !item->children()->isEmpty()) { // container
TQSize s;
if(item->container() && item->container()->tqlayout())
s = w->sizeHint();
@@ -545,17 +545,17 @@ AdjustSizeCommand::getSizeFromChildren(ObjectTreeItem *item)
{
TQSize s;
// get size for each container, and keep the biggest one
- for(ObjectTreeItem *tree = item->tqchildren()->first(); tree; tree = item->tqchildren()->next())
+ for(ObjectTreeItem *tree = item->children()->first(); tree; tree = item->children()->next())
s = s.expandedTo(getSizeFromChildren(tree));
return s;
}
int tmpw = 0, tmph = 0;
- for(ObjectTreeItem *tree = item->tqchildren()->first(); tree; tree = item->tqchildren()->next()) {
+ for(ObjectTreeItem *tree = item->children()->first(); tree; tree = item->children()->next()) {
if(!tree->widget())
continue;
- tmpw = TQMAX(tmpw, tree->widget()->tqgeometry().right());
- tmph = TQMAX(tmph, tree->widget()->tqgeometry().bottom());
+ tmpw = TQMAX(tmpw, tree->widget()->geometry().right());
+ tmph = TQMAX(tmph, tree->widget()->geometry().bottom());
}
return TQSize(tmpw, tmph) + TQSize(10, 10);
@@ -621,9 +621,9 @@ LayoutPropertyCommand::LayoutPropertyCommand(WidgetPropertySet *buf, const TQCSt
if (!titem)
return; //better this than a crash
Container *m_container = titem->container();
- // We save the tqgeometry of each wigdet
- for(ObjectTreeItem *it = m_container->objectTree()->tqchildren()->first(); it; it = m_container->objectTree()->tqchildren()->next())
- m_geometries.insert(it->name().latin1(), it->widget()->tqgeometry());
+ // We save the geometry of each wigdet
+ for(ObjectTreeItem *it = m_container->objectTree()->children()->first(); it; it = m_container->objectTree()->children()->next())
+ m_geometries.insert(it->name().latin1(), it->widget()->geometry());
}
void
@@ -655,7 +655,7 @@ LayoutPropertyCommand::unexecute()
TQString
LayoutPropertyCommand::name() const
{
- return i18n("Change tqlayout of widget \"%1\"").tqarg(TQString(m_oldvalues.begin().key()));
+ return i18n("Change tqlayout of widget \"%1\"").arg(TQString(m_oldvalues.begin().key()));
}
void
@@ -740,7 +740,7 @@ InsertWidgetCommand::execute()
WidgetInfo *winfo = m_container->form()->library()->widgetInfoForClassName(m_class);
KMessageBox::sorry(FormManager::self()->activeForm() ? FormManager::self()->activeForm()->widget() : 0,
i18n("Could not insert widget of type \"%1\". A problem with widget's creation encountered.")
- .tqarg(winfo ? winfo->name() : TQString()));
+ .arg(winfo ? winfo->name() : TQString()));
kdWarning() << "InsertWidgetCommand::execute() ERROR: widget creation failed" << endl;
return;
}
@@ -830,7 +830,7 @@ TQString
InsertWidgetCommand::name() const
{
if(!m_name.isEmpty())
- return i18n("Insert widget \"%1\"").tqarg(TQString(m_name));
+ return i18n("Insert widget \"%1\"").arg(TQString(m_name));
else
return i18n("Insert widget");
}
@@ -867,7 +867,7 @@ CreateLayoutCommand::CreateLayoutCommand(int layoutType, WidgetList &list, Form
m_list->sort(); // we sort them now, before creating the tqlayout
for(TQWidget *w = m_list->first(); w; w = m_list->next())
- m_pos.insert(w->name(), w->tqgeometry());
+ m_pos.insert(w->name(), w->geometry());
ObjectTreeItem *item = form->objectTree()->lookup(m_list->first()->name());
if(item && item->parent()->container())
m_containername = item->parent()->name();
@@ -912,7 +912,7 @@ CreateLayoutCommand::execute()
container->setSelectedWidget(0, false);
w->move(m_pos.begin().data().topLeft()); // we move the tqlayout at the position of the topleft widget
// sizeHint of these widgets depends on tqgeometry, so give them appropriate tqgeometry
if(m_type == Container::HFlow)
w->resize( TQSize(700, 20) );
else if(m_type == Container::VFlow)
@@ -1019,7 +1019,7 @@ BreakLayoutCommand::BreakLayoutCommand(Container *container)
m_form = container->form();
m_type = container->layoutType();
- for(ObjectTreeItem *tree = container->objectTree()->tqchildren()->first(); tree; tree = container->objectTree()->tqchildren()->next())
+ for(ObjectTreeItem *tree = container->objectTree()->children()->first(); tree; tree = container->objectTree()->children()->next())
{
TQRect r(container->widget()->mapTo(container->widget()->parentWidget(), tree->widget()->pos()), tree->widget()->size());
m_pos.insert(tree->widget()->name(), r);
@@ -1041,7 +1041,7 @@ BreakLayoutCommand::unexecute()
TQString
BreakLayoutCommand::name() const
{
- return i18n("Break Layout: \"%1\"").tqarg(m_name);
+ return i18n("Break Layout: \"%1\"").arg(m_name);
}
void
@@ -1208,7 +1208,7 @@ PasteWidgetCommand::changePos(TQDomElement &el, const TQPoint &newpos)
{
//TQDomElement el = widg.cloneNode(true).toElement();
TQDomElement rect;
// Find the widget tqgeometry if there is one
for(TQDomNode n = el.firstChild(); !n.isNull(); n = n.nextSibling())
{
if((n.toElement().tagName() == "property") && (n.toElement().attribute("name") == "geometry"))
@@ -1253,7 +1253,7 @@ PasteWidgetCommand::fixPos(TQDomElement &el, Container *container)
if(!w)
return;
- while((w->tqgeometry() == r) && (w != 0))// there is already a widget there, with the same size
+ while((w->geometry() == r) && (w != 0))// there is already a widget there, with the same size
{
w = m_form->widget()->childAt(w->x() + 16, w->y() + 16, false);
r.moveBy(10,10);
@@ -1302,7 +1302,7 @@ PasteWidgetCommand::moveWidgetBy(TQDomElement &el, Container *container, const T
TQWidget *w = m_form->widget()->childAt(r.x() + 6, r.y() + 6, false);
- while(w && (w->tqgeometry() == r))// there is already a widget there, with the same size
+ while(w && (w->geometry() == r))// there is already a widget there, with the same size
{
w = m_form->widget()->childAt(w->x() + 16, w->y() + 16, false);
r.moveBy(10,10);
@@ -912,7 +912,7 @@ CreateLayoutCommand::execute()
container->setSelectedWidget(0, false);
w->move(m_pos.begin().data().topLeft()); // we move the tqlayout at the position of the topleft widget
- // sizeHint of these widgets depends on tqgeometry, so give them appropriate tqgeometry
+ // sizeHint of these widgets depends on geometry, so give them appropriate geometry
if(m_type == Container::HFlow)
w->resize( TQSize(700, 20) );
@@ -1208,7 +1208,7 @@ PasteWidgetCommand::changePos(TQDomElement &el, const TQPoint &newpos)
//TQDomElement el = widg.cloneNode(true).toElement();
TQDomElement rect;
- // Find the widget tqgeometry if there is one
+ // Find the widget geometry if there is one
for(TQDomNode n = el.firstChild(); !n.isNull(); n = n.nextSibling())
{
diff --git a/kexi/formeditor/container.cpp b/kexi/formeditor/container.cpp
index d1275adc2..706ef69ba 100644
--- a/kexi/formeditor/container.cpp
+++ b/kexi/formeditor/container.cpp
@@ -73,7 +73,7 @@ EventEater::eventFilter(TQObject *, TQEvent *ev)
}
}
// else if(ev->type() == TQEvent::ChildInserted) {
// widget's tqchildren have changed, we need to reinstall filter
// installRecursiveEventFilter(m_widget, this);
// }
@@ -180,7 +180,7 @@ Container::eventFilter(TQObject *s, TQEvent *e)
unSelectWidget(m_moving);
else // the widget is the only selected, so it means we want to copy it
{
- //m_copyRect = m_moving->tqgeometry();
+ //m_copyRect = m_moving->geometry();
m_state = CopyingWidget;
if(m_form->formWidget())
m_form->formWidget()->initBuffer();
@@ -408,7 +408,7 @@ Container::eventFilter(TQObject *s, TQEvent *e)
ObjectTreeItem *item = form()->objectTree()->lookup(form()->selectedWidgets()->first()->name());
if(!item || !item->parent())
return true;
- ObjectTreeList *list = item->parent()->tqchildren();
+ ObjectTreeList *list = item->parent()->children();
if(list->count() == 1)
return true;
int index = list->findRef(item);
@@ -639,7 +639,7 @@ Container::setLayout(LayoutType type)
return;
}
}
- m_container->setGeometry(m_container->tqgeometry()); // just update tqlayout
+ m_container->setGeometry(m_container->geometry()); // just update tqlayout
m_layout->activate();
}
@@ -656,7 +656,7 @@ Container::createBoxLayout(WidgetList *list)
{
TQBoxLayout *tqlayout = static_cast<TQBoxLayout*>(m_layout);
- for(ObjectTreeItem *tree = m_tree->tqchildren()->first(); tree; tree = m_tree->tqchildren()->next())
+ for(ObjectTreeItem *tree = m_tree->children()->first(); tree; tree = m_tree->children()->next())
list->append( tree->widget());
list->sort();
@@ -669,7 +669,7 @@ void
Container::createFlowLayout()
{
KexiFlowLayout *flow = dynamic_cast<KexiFlowLayout*>(m_layout);
- if(!flow || m_tree->tqchildren()->isEmpty())
+ if(!flow || m_tree->children()->isEmpty())
return;
const int offset = 15;
@@ -684,7 +684,7 @@ Container::createFlowLayout()
}
// fill the list
- for(ObjectTreeItem *tree = m_tree->tqchildren()->first(); tree; tree = m_tree->tqchildren()->next())
+ for(ObjectTreeItem *tree = m_tree->children()->first(); tree; tree = m_tree->children()->next())
list->append( tree->widget());
list->sort();
@@ -741,11 +741,11 @@ Container::createGridLayout(bool testOnly)
int end=-1000;
bool same = false;
- for(ObjectTreeItem *tree = m_tree->tqchildren()->first(); tree; tree = m_tree->tqchildren()->next())
+ for(ObjectTreeItem *tree = m_tree->children()->first(); tree; tree = m_tree->children()->next())
vlist->append( tree->widget());
vlist->sort();
- for(ObjectTreeItem *tree = m_tree->tqchildren()->first(); tree; tree = m_tree->tqchildren()->next())
+ for(ObjectTreeItem *tree = m_tree->children()->first(); tree; tree = m_tree->children()->next())
hlist->append( tree->widget());
hlist->sort();
@@ -759,19 +759,19 @@ Container::createGridLayout(bool testOnly)
for(; it2.current() != 0; ++it2) {
TQWidget *nextw = it2.current();
- if((w->y() >= nextw->y()) || (nextw->y() >= w->tqgeometry().bottom()))
+ if((w->y() >= nextw->y()) || (nextw->y() >= w->geometry().bottom()))
break;
- if(!w->tqgeometry().intersects(nextw->tqgeometry()))
+ if(!w->geometry().intersects(nextw->geometry()))
break;
// If the geometries of the two widgets intersect each other,
// we move one of the widget to the rght or bottom of the other
if((nextw->y() - w->y()) > abs(nextw->x() - w->x()))
- nextw->move(nextw->x(), w->tqgeometry().bottom()+1);
+ nextw->move(nextw->x(), w->geometry().bottom()+1);
else if(nextw->x() >= w->x())
- nextw->move(w->tqgeometry().right()+1, nextw->y());
+ nextw->move(w->geometry().right()+1, nextw->y());
else
- w->move(nextw->tqgeometry().right()+1, nextw->y());
+ w->move(nextw->geometry().right()+1, nextw->y());
}
}
}
@@ -782,7 +782,7 @@ Container::createGridLayout(bool testOnly)
TQWidget *w = it.current();
WidgetListIterator it2 = it;
if(!same) { // this widget will make a new row
- end = w->tqgeometry().bottom();
+ end = w->geometry().bottom();
rows.append(w->y());
}
@@ -796,9 +796,9 @@ Container::createGridLayout(bool testOnly)
if(nextw->y() >= end)
same = false;
else {
- same = !(same && (nextw->y() >= w->tqgeometry().bottom()));
+ same = !(same && (nextw->y() >= w->geometry().bottom()));
if(!same)
- end = w->tqgeometry().bottom();
+ end = w->geometry().bottom();
}
}
kdDebug() << "the new grid will have n rows: n == " << rows.size() << endl;
@@ -811,7 +811,7 @@ Container::createGridLayout(bool testOnly)
TQWidget *w = it.current();
WidgetListIterator it2 = it;
if(!same) {
- end = w->tqgeometry().right();
+ end = w->geometry().right();
cols.append(w->x());
}
@@ -823,9 +823,9 @@ Container::createGridLayout(bool testOnly)
if(nextw->x() >= end)
same = false;
else {
- same = !(same && (nextw->x() >= w->tqgeometry().right()));
+ same = !(same && (nextw->x() >= w->geometry().right()));
if(!same)
- end = w->tqgeometry().right();
+ end = w->geometry().right();
}
}
kdDebug() << "the new grid will have n columns: n == " << cols.size() << endl;
@@ -841,7 +841,7 @@ Container::createGridLayout(bool testOnly)
for(WidgetListIterator it(*vlist); it.current() != 0; ++it)
{
TQWidget *w = it.current();
- TQRect r = w->tqgeometry();
+ TQRect r = w->geometry();
uint wcol=0, wrow=0, endrow=0, endcol=0;
uint i = 0;
@@ -971,7 +971,7 @@ Container::drawConnection(TQMouseEvent *mev)
{
FormManager::self()->createdConnection()->setReceiver(m_moving->name());
FormManager::self()->createSlotMenu(m_moving);
- m_container->tqrepaint();
+ m_container->repaint();
return;
}
// the user clicked outside the menu, we cancel the connection
@@ -997,12 +997,12 @@ Container::drawSelectionRect(TQMouseEvent *mev)
setSelectedWidget(m_container, false);
TQWidget *widgetToSelect = 0;
// We check which widgets are in the rect and select them
- for(ObjectTreeItem *item = m_tree->tqchildren()->first(); item; item = m_tree->tqchildren()->next())
+ for(ObjectTreeItem *item = m_tree->children()->first(); item; item = m_tree->children()->next())
{
TQWidget *w = item->widget();
if(!w)
continue;
- if(w->tqgeometry().intersects(r) && w != m_container) {
+ if(w->geometry().intersects(r) && w != m_container) {
if (widgetToSelect)
setSelectedWidget(widgetToSelect, true/*add*/, false/*raise*/, true/*moreWillBeSelected*/);
widgetToSelect = w; //select later
@@ -1013,7 +1013,7 @@ Container::drawSelectionRect(TQMouseEvent *mev)
m_insertRect = TQRect();
m_state = DoingNothing;
- m_container->tqrepaint();
+ m_container->repaint();
}
void
@@ -1070,7 +1070,7 @@ Container::drawCopiedWidgetRect(TQMouseEvent *mev)
//FormManager::self()->undo(); // undo last moving
//m_moving->move(m_initialPos);
if(m_form->formWidget()) {
- m_container->tqrepaint();
+ m_container->repaint();
m_form->formWidget()->initBuffer();
}
m_state = CopyingWidget;
@@ -1081,7 +1081,7 @@ Container::drawCopiedWidgetRect(TQMouseEvent *mev)
if(m_form->formWidget()) {
TQValueList<TQRect> rectList;
for(TQWidget *w = m_form->selectedWidgets()->first(); w; w = m_form->selectedWidgets()->next()) {
- TQRect drawRect = w->tqgeometry();
+ TQRect drawRect = w->geometry();
TQPoint p = mev->pos() - m_grab;
drawRect.moveBy(p.x(), p.y());
p = m_container->mapTo(m_form->widget(), TQPoint(0, 0));
@@ -73,7 +73,7 @@ EventEater::eventFilter(TQObject *, TQEvent *ev)
}
// else if(ev->type() == TQEvent::ChildInserted) {
- // widget's tqchildren have changed, we need to reinstall filter
+ // widget's children have changed, we need to reinstall filter
// installRecursiveEventFilter(m_widget, this);
// }
diff --git a/kexi/formeditor/formIO.cpp b/kexi/formeditor/formIO.cpp
index 24347c40f..9161049db 100644
--- a/kexi/formeditor/formIO.cpp
+++ b/kexi/formeditor/formIO.cpp
@@ -621,7 +621,7 @@ FormIO::writeVariant(TQDomDocument &parent, TQDomElement &parentNode, TQVariant
case TQVariant::Cursor:
{
type = parent.createElement("cursor");
- valueE = parent.createTextNode(TQString::number(value.toCursor().tqshape()));
+ valueE = parent.createTextNode(TQString::number(value.toCursor().shape()));
type.appendChild(valueE);
break;
}
@@ -964,14 +964,14 @@ FormIO::saveWidget(ObjectTreeItem *item, TQDomElement &parent, TQDomDocument &do
savePropertyValue(tclass, domDoc, "name", item->widget()->property("name"), item->widget());
// Important: save dataSource property FIRST before properties like "tqalignment"
// - needed when subproperties are defined after subwidget creation, and subwidget is created after setting "dataSource"
// (this is the case for KexiDBAutoField)
//! @todo more properties like "dataSource" may needed here...
// if (-1 != item->widget()->metaObject()->findProperty("dataSource"))
// savePropertyValue(tclass, domDoc, "dataSource", item->widget()->property("dataSource"), item->widget());
- // We don't want to save the tqgeometry if the widget is inside a tqlayout (so parent.tagName() == "grid" for example)
+ // We don't want to save the geometry if the widget is inside a tqlayout (so parent.tagName() == "grid" for example)
if(item && !item->parent()) {
// save form widget size, but not its position
savePropertyValue(tclass, domDoc, "geometry",
@@ -992,10 +992,10 @@ FormIO::saveWidget(ObjectTreeItem *item, TQDomElement &parent, TQDomDocument &do
for(TQMap<TQString,TQVariant>::ConstIterator it = map->constBegin(); it != endIt; ++it)
{
const TQCString name( it.key().latin1() );
- if(name == "hAlign" || name == "vAlign" || name == "wordbreak" || name == "tqalignment") {
+ if(name == "hAlign" || name == "vAlign" || name == "wordbreak" || name == "alignment") {
if(!savedAlignment) // not to save it twice
{
- savePropertyValue(tclass, domDoc, "tqalignment", item->widget()->property("tqalignment"), item->widget());
+ savePropertyValue(tclass, domDoc, "alignment", item->widget()->property("alignment"), item->widget());
savedAlignment = true;
}
}
@@ -1038,13 +1038,13 @@ FormIO::saveWidget(ObjectTreeItem *item, TQDomElement &parent, TQDomDocument &do
case Container::Grid: // grid tqlayout
{
tqlayout.setTagName("grid");
- for(ObjectTreeItem *objIt = item->tqchildren()->first(); objIt; objIt = item->tqchildren()->next())
+ for(ObjectTreeItem *objIt = item->children()->first(); objIt; objIt = item->children()->next())
saveWidget(objIt, tqlayout, domDoc, true);
break;
}
case Container::HBox: case Container::VBox:
{
- // as we don't save tqgeometry, we need to sort widgets in the right order, not creation order
+ // as we don't save geometry, we need to sort widgets in the right order, not creation order
WidgetList *list;
if(tqlayout.tagName() == "hbox") {
list = new HorWidgetList(item->container()->form()->toplevelContainer()->widget());
@@ -1055,7 +1055,7 @@ FormIO::saveWidget(ObjectTreeItem *item, TQDomElement &parent, TQDomDocument &do
tqlayout.setTagName("vbox");
}
- for(ObjectTreeItem *objTree = item->tqchildren()->first(); objTree; objTree = item->tqchildren()->next())
+ for(ObjectTreeItem *objTree = item->children()->first(); objTree; objTree = item->children()->next())
list->append(objTree->widget());
list->sort();
@@ -1090,7 +1090,7 @@ FormIO::saveWidget(ObjectTreeItem *item, TQDomElement &parent, TQDomDocument &do
}
default:
{
- for(ObjectTreeItem *objIt = item->tqchildren()->first(); objIt; objIt = item->tqchildren()->next())
+ for(ObjectTreeItem *objIt = item->children()->first(); objIt; objIt = item->children()->next())
saveWidget(objIt, tclass, domDoc);
}
}
@@ -1391,7 +1391,7 @@ FormIO::readChildNodes(ObjectTreeItem *item, Container *container, const TQDomEl
{
TQVariant val( readPropertyValue(node.firstChild(), TQT_TQOBJECT(w), name) );
if(name == "geometry" && dynamic_cast<FormWidget*>(w)) {
- //fix tqgeometry if needed - this is top level form widget
+ //fix geometry if needed - this is top level form widget
TQRect r( val.toRect() );
if (r.left()<0) //negative X!
r.moveLeft(0);
@@ -964,14 +964,14 @@ FormIO::saveWidget(ObjectTreeItem *item, TQDomElement &parent, TQDomDocument &do
savePropertyValue(tclass, domDoc, "name", item->widget()->property("name"), item->widget());
- // Important: save dataSource property FIRST before properties like "tqalignment"
+ // Important: save dataSource property FIRST before properties like "alignment"
// - needed when subproperties are defined after subwidget creation, and subwidget is created after setting "dataSource"
// (this is the case for KexiDBAutoField)
diff --git a/kexi/formeditor/utils.h b/kexi/formeditor/utils.h
index 5107b45c6..d6d56acbb 100644
--- a/kexi/formeditor/utils.h
+++ b/kexi/formeditor/utils.h
@@ -94,18 +94,18 @@ class VerWidgetList : public WidgetList
KFORMEDITOR_EXPORT void removeChildrenFromList(WidgetList &list);
/*! This helper function install an event filter on \a object and all of its
- tqchildren, directed to \a container.
+ children, directed to \a container.
This is necessary to filter events for composed widgets. */
KFORMEDITOR_EXPORT void installRecursiveEventFilter(TQObject *object, TQObject *container);
/*! This helper function removes an event filter installed before
- on \a object and all of its tqchildren.
+ on \a object and all of its children.
This is necessary to filter events for composed widgets. */
KFORMEDITOR_EXPORT void removeRecursiveEventFilter(TQObject *object, TQObject *container);
KFORMEDITOR_EXPORT void setRecursiveCursor(TQWidget *w, Form *form);
/*! \return the size of \a w tqchildren. This can be used eg to get widget's sizeHint. */
KFORMEDITOR_EXPORT TQSize getSizeFromChildren(TQWidget *widget, const char *inheritClass=TQWIDGET_OBJECT_NAME_STRING);
}
@@ -94,18 +94,18 @@ class VerWidgetList : public WidgetList
KFORMEDITOR_EXPORT void removeRecursiveEventFilter(TQObject *object, TQObject *container);
KFORMEDITOR_EXPORT void setRecursiveCursor(TQWidget *w, Form *form);
-/*! \return the size of \a w tqchildren. This can be used eg to get widget's sizeHint. */
+/*! \return the size of \a w children. This can be used eg to get widget's sizeHint. */
KFORMEDITOR_EXPORT TQSize getSizeFromChildren(TQWidget *widget, const char *inheritClass=TQWIDGET_OBJECT_NAME_STRING);
}
diff --git a/kexi/formeditor/widgetpropertyset.cpp b/kexi/formeditor/widgetpropertyset.cpp
index 5ed8f96d4..8d7d7daf9 100644
--- a/kexi/formeditor/widgetpropertyset.cpp
+++ b/kexi/formeditor/widgetpropertyset.cpp
@@ -253,7 +253,7 @@ WidgetPropertySet::addWidget(TQWidget *w)
//second widget, update metainfo
d->set["this:className"].setValue("special:multiple");
d->set["this:classString"].setValue(
- i18n("Multiple Widgets") + TQString(" (%1)").tqarg(d->widgets.count()) );
+ i18n("Multiple Widgets") + TQString(" (%1)").arg(d->widgets.count()) );
d->set["this:iconName"].setValue("multiple_obj");
//name doesn't make sense for now
d->set["name"].setValue("");
@@ -328,7 +328,7 @@ WidgetPropertySet::createPropertiesForWidget(TQWidget *w)
const bool oldValueExists = modifiedPropertiesIt!=modifiedProperties->constEnd();
if(meta->isEnumType()) {
- if(qstrcmp(propertyName, "tqalignment") == 0) {
+ if(qstrcmp(propertyName, "alignment") == 0) {
createAlignProperty(meta, w, subwidget);
continue;
}
@@ -678,7 +678,7 @@ WidgetPropertySet::isNameValid(const TQString &name)
KMessageBox::sorry(KFormDesigner::FormManager::self()->activeForm()->widget(),
i18n("Could not rename widget \"%1\" to \"%2\" because "
"\"%3\" is not a valid name (identifier) for a widget.\n")
- .tqarg(w->name()).tqarg(name).tqarg(name));
+ .arg(w->name()).arg(name).arg(name));
d->slotPropertyChangedEnabled = false;
d->set["name"].resetValue();
d->slotPropertyChangedEnabled = true;
@@ -689,7 +689,7 @@ WidgetPropertySet::isNameValid(const TQString &name)
KMessageBox::sorry( KFormDesigner::FormManager::self()->activeForm()->widget(),
i18n("Could not rename widget \"%1\" to \"%2\" "
"because a widget with the name \"%3\" already exists.\n")
- .tqarg(w->name()).tqarg(name).tqarg(name));
+ .arg(w->name()).arg(name).arg(name));
d->slotPropertyChangedEnabled = false;
d->set["name"].resetValue();
d->slotPropertyChangedEnabled = true;
@@ -740,7 +740,7 @@ WidgetPropertySet::eventFilter(TQObject *o, TQEvent *ev)
if(d->set["geometry"].value() == o->property("geometry")) // to avoid infinite recursion
return false;
- d->set["geometry"] = TQT_TQWIDGET(o)->tqgeometry();
+ d->set["geometry"] = TQT_TQWIDGET(o)->geometry();
}
}
else if(d->widgets.count() > 1 && ev->type() == TQEvent::Move) // the widget is being moved, we update the property
@@ -775,8 +775,8 @@ WidgetPropertySet::createAlignProperty(const TQMetaProperty *meta, TQWidget *wid
TQStringList list;
TQString value;
- const int tqalignment = subwidget->property("tqalignment").toInt();
- const TQStringList keys( TQStringList::fromStrList( meta->valueToKeys(tqalignment) ) );
+ const int alignment = subwidget->property("alignment").toInt();
+ const TQStringList keys( TQStringList::fromStrList( meta->valueToKeys(alignment) ) );
TQStrList *enumKeys = new TQStrList(meta->enumKeys());
const TQStringList possibleValues( TQStringList::fromStrList(*enumKeys) );
@@ -786,7 +786,7 @@ WidgetPropertySet::createAlignProperty(const TQMetaProperty *meta, TQWidget *wid
bool isTopLevel = KFormDesigner::FormManager::self()->isTopLevel(widget);
if(possibleValues.find("AlignHCenter")!=possibleValues.constEnd()) {
// Create the horizontal tqalignment property
if(keys.find("AlignHCenter")!=keys.constEnd() || keys.find("AlignCenter")!=keys.constEnd())
value = "AlignHCenter";
else if(keys.find("AlignRight")!=keys.constEnd())
@@ -812,7 +812,7 @@ WidgetPropertySet::createAlignProperty(const TQMetaProperty *meta, TQWidget *wid
if(possibleValues.find("AlignTop")!=possibleValues.constEnd())
{
// Create the ver tqalignment property
if(keys.find("AlignTop")!=keys.constEnd())
value = "AlignTop";
else if(keys.find("AlignBottom")!=keys.constEnd())
@@ -837,7 +837,7 @@ WidgetPropertySet::createAlignProperty(const TQMetaProperty *meta, TQWidget *wid
) {
// Create the wordbreak property
KoProperty::Property *p = new KoProperty::Property("wordbreak",
- TQVariant(tqalignment & TQt::WordBreak, 3), i18n("Word Break"), i18n("Word Break") );
+ TQVariant(alignment & TQt::WordBreak, 3), i18n("Word Break"), i18n("Word Break") );
d->set.addProperty(p);
updatePropertyValue(tree, "wordbreak");
if (!KFormDesigner::FormManager::self()->activeForm()->library()->isPropertyVisible(
@@ -865,9 +865,9 @@ WidgetPropertySet::saveAlignProperty(const TQString &property)
WidgetWithSubpropertiesInterface* subpropIface = dynamic_cast<WidgetWithSubpropertiesInterface*>(
(TQWidget*)d->widgets.first() );
TQWidget *subwidget = (subpropIface && subpropIface->subwidget()) ? subpropIface->subwidget() : (TQWidget*)d->widgets.first();
- int count = subwidget->metaObject()->findProperty("tqalignment", true);
+ int count = subwidget->metaObject()->findProperty("alignment", true);
const TQMetaProperty *meta = subwidget->metaObject()->property(count, true);
- subwidget->setProperty("tqalignment", meta->keysToValue(list));
+ subwidget->setProperty("alignment", meta->keysToValue(list));
ObjectTreeItem *tree = KFormDesigner::FormManager::self()->activeForm()->objectTree()->lookup(
d->widgets.first()->name() );
@@ -877,11 +877,11 @@ WidgetPropertySet::saveAlignProperty(const TQString &property)
if(d->isUndoing)
return;
- if(d->lastCommand && d->lastCommand->property() == "tqalignment")
+ if(d->lastCommand && d->lastCommand->property() == "alignment")
d->lastCommand->setValue(meta->keysToValue(list));
else {
d->lastCommand = new PropertyCommand(this, d->widgets.first()->name(),
- subwidget->property("tqalignment"), meta->keysToValue(list), "tqalignment");
+ subwidget->property("alignment"), meta->keysToValue(list), "alignment");
KFormDesigner::FormManager::self()->activeForm()->addCommand(d->lastCommand, false);
}
}
@@ -786,7 +786,7 @@ WidgetPropertySet::createAlignProperty(const TQMetaProperty *meta, TQWidget *wid
bool isTopLevel = KFormDesigner::FormManager::self()->isTopLevel(widget);
if(possibleValues.find("AlignHCenter")!=possibleValues.constEnd()) {
- // Create the horizontal tqalignment property
+ // Create the horizontal alignment property
if(keys.find("AlignHCenter")!=keys.constEnd() || keys.find("AlignCenter")!=keys.constEnd())
value = "AlignHCenter";
@@ -812,7 +812,7 @@ WidgetPropertySet::createAlignProperty(const TQMetaProperty *meta, TQWidget *wid
if(possibleValues.find("AlignTop")!=possibleValues.constEnd())
{
- // Create the ver tqalignment property
+ // Create the ver alignment property
if(keys.find("AlignTop")!=keys.constEnd())
value = "AlignTop";
diff --git a/kexi/formeditor/widgetpropertyset.h b/kexi/formeditor/widgetpropertyset.h
index afb303d1a..f1f96a99f 100644
--- a/kexi/formeditor/widgetpropertyset.h
+++ b/kexi/formeditor/widgetpropertyset.h
@@ -157,15 +157,15 @@ class KFORMEDITOR_EXPORT WidgetPropertySet : public TQObject
// Following functions are used to create special types of properties, different
// from TQ_PROPERTY
/*! Creates the properties related to tqalignment (ie hAlign, vAlign and WordBreak) for
the TQWidget \a widget. \a subwidget is the same as \a widget if the widget itself handles
the property and it's a child widget if the child handles the property.
For example, the second case is true for KexiDBAutoField.
- \a meta is the TQMetaProperty for "tqalignment" property" of subwidget. */
+ \a meta is the TQMetaProperty for "alignment" property" of subwidget. */
void createAlignProperty(const TQMetaProperty *meta, TQWidget *widget, TQWidget *subwidget);
- /*! Saves the properties related to tqalignment (ie hAlign, vAlign and WordBreak)
- and modifies the "tqalignment" property of the widget.*/
+ /*! Saves the properties related to alignment (ie hAlign, vAlign and WordBreak)
+ and modifies the "alignment" property of the widget.*/
void saveAlignProperty(const TQString &property);
/*! Creates the "tqlayout" property, for the Container representing \a item. */
@@ -157,15 +157,15 @@ class KFORMEDITOR_EXPORT WidgetPropertySet : public TQObject
// Following functions are used to create special types of properties, different
// from TQ_PROPERTY
- /*! Creates the properties related to tqalignment (ie hAlign, vAlign and WordBreak) for
+ /*! Creates the properties related to alignment (ie hAlign, vAlign and WordBreak) for
the TQWidget \a widget. \a subwidget is the same as \a widget if the widget itself handles
the property and it's a child widget if the child handles the property.